@@ -21,9 +21,6 @@ class IMDB_Networkx_Arango_Adapter(Networkx_Arango_Adapter):
         
         self.cfg = None
         if graph_config is None:
-            file_exists = os.path.exists(graph_desc_save_fp)
-            if not file_exists:
-                print("Graph descriptor file does not exist, please provide config information. !")
             self.gdesc_file = graph_desc_save_fp
             self.cfg = self.read_data()
         else:
